<?php
/**
 * Plugin Name: Cookie Consent Banner
 * Description: A simple plugin to display a cookie consent banner with a modal style.
 * Version: 1.2.1
 * Author: Vladislaw
 * License: GPL2
 */

function cookie_consent_enqueue_scripts() {
    wp_enqueue_style('cookie-consent-style', plugin_dir_url(__FILE__) . 'css/style.css');
    wp_enqueue_script('cookie-consent-script', plugin_dir_url(__FILE__) . 'js/cookie-consent.js', array(), '1.0', true);
    wp_enqueue_style('font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css');
}

add_action('wp_enqueue_scripts', 'cookie_consent_enqueue_scripts');

function cookie_consent_admin_menu() {
    add_menu_page(
        'Настройки на банера за съгласие с бисквитки',
        'Cookie Consent', 
        'manage_options', 
        'cookie-consent-settings', 
        'cookie_consent_settings_page', 
        'dashicons-admin-tools', 
        80 
    );
}

add_action('admin_menu', 'cookie_consent_admin_menu');

function cookie_consent_settings_page() {
    ?>
    <div class="wrap">
        <h1>Настройки на банера за съгласие с бисквитки</h1>
        <h4>от <a href="https://wpplug.info">WPplug.info</a> / версия 1.2.1</h4>
        
        <form method="post" action="options.php">
            <?php
            settings_fields('cookie_consent_settings_group');
            do_settings_sections('cookie-consent-settings');
            ?>
            
            <table class="form-table">
                <tr>
                    <th scope="row">Цвят на бутона</th>
                    <td>
                        <input type="color" name="cookie_consent_button_color" value="<?php echo esc_attr(get_option('cookie_consent_button_color', '#007bff')); ?>">
                    </td>
                </tr>
                <tr>
                    <th scope="row">Текст за съобщението</th>
                    <td>
                        <textarea name="cookie_consent_message_text" rows="5" cols="50"><?php echo esc_textarea(get_option('cookie_consent_message_text', 'Използваме бисквитки за персонализирана реклама и анализ на потребителското поведение. Можете да промените настройките си за бисквитки по всяко време чрез бутоните по-долу или в настройките за поверителност.')); ?></textarea>
                        <p>Текстът, който ще се показва в банера.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Анимация на банера</th>
                    <td>
                        <select name="cookie_consent_animation">
                            <option value="fade" <?php selected(get_option('cookie_consent_animation', 'fade'), 'fade'); ?>>Fade-in</option>
                            <option value="slide" <?php selected(get_option('cookie_consent_animation', 'fade'), 'slide'); ?>>Slide-up</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Срок на съгласие (в дни)</th>
                    <td>
                        <input type="number" name="cookie_consent_expiration" value="<?php echo esc_attr(get_option('cookie_consent_expiration', '30')); ?>" min="1">
                        <p>След този период банерът ще бъде показан отново, ако потребителят е приел.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Линк към политика за конфиденциалност</th>
                    <td>
                        <input type="text" name="cookie_consent_privacy_link" value="<?php echo esc_attr(get_option('cookie_consent_privacy_link', '/privacy-policy')); ?>">
                        <p>Въведете линк към страницата с политика за конфиденциалност.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Включване/изключване за мобилни устройства</th>
                    <td>
                        <input type="checkbox" name="cookie_consent_mobile_enabled" value="1" <?php checked(1, get_option('cookie_consent_mobile_enabled', 1)); ?>>
                        <p>Активирайте или деактивирайте банера за мобилни устройства.</p>
                    </td>
                </tr>

                <tr>
                    <th scope="row">Текст за персонализирана реклама</th>
                    <td>
                        <textarea name="cookie_consent_advertising_text" rows="5" cols="50"><?php echo esc_textarea(get_option('cookie_consent_advertising_text', 'Персонализирана реклама и съдържание, измерване на рекламата и съдържанието, проучване на аудиторията и разработване на услуги')); ?></textarea>
                        <p>Текстът, който ще се показва за персонализирана реклама.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Активиране на персонализирана реклама</th>
                    <td>
                        <input type="checkbox" name="cookie_consent_advertising_enabled" value="1" <?php checked(1, get_option('cookie_consent_advertising_enabled', 1)); ?>>
                        <p>Изберете дали да се показва текста за персонализирана реклама.</p>
                    </td>
                </tr>

                <tr>
                    <th scope="row">Текст за съхранение на информация</th>
                    <td>
                        <textarea name="cookie_consent_device_storage_text" rows="5" cols="50"><?php echo esc_textarea(get_option('cookie_consent_device_storage_text', 'Съхраняване на и/или достъп до информация на устройство')); ?></textarea>
                        <p>Текстът, който ще се показва за съхранение на информация на устройство.</p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Активиране на съхранение на информация</th>
                    <td>
                        <input type="checkbox" name="cookie_consent_device_storage_enabled" value="1" <?php checked(1, get_option('cookie_consent_device_storage_enabled', 1)); ?>>
                        <p>Изберете дали да се показва текста за съхранение на информация на устройство.</p>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

function cookie_consent_register_settings() {
    register_setting('cookie_consent_settings_group', 'cookie_consent_button_color');
    register_setting('cookie_consent_settings_group', 'cookie_consent_message_text');
    register_setting('cookie_consent_settings_group', 'cookie_consent_animation');
    register_setting('cookie_consent_settings_group', 'cookie_consent_expiration');
    register_setting('cookie_consent_settings_group', 'cookie_consent_privacy_link');
    register_setting('cookie_consent_settings_group', 'cookie_consent_mobile_enabled');
    
    // Нови опции за текстовете
    register_setting('cookie_consent_settings_group', 'cookie_consent_advertising_text');
    register_setting('cookie_consent_settings_group', 'cookie_consent_device_storage_text');
    register_setting('cookie_consent_settings_group', 'cookie_consent_advertising_enabled');
    register_setting('cookie_consent_settings_group', 'cookie_consent_device_storage_enabled');
}

add_action('admin_init', 'cookie_consent_register_settings');

function cookie_consent_banner() {
    if (wp_is_mobile() && get_option('cookie_consent_mobile_enabled', 1) == 0) {
        return;
    }

    $button_color = get_option('cookie_consent_button_color', '#007bff');
    $animation = get_option('cookie_consent_animation', 'fade');
    $expiration = get_option('cookie_consent_expiration', 30);
    $privacy_link = get_option('cookie_consent_privacy_link', '/privacy-policy');
    $message_text = get_option('cookie_consent_message_text');
    $advertising_enabled = get_option('cookie_consent_advertising_enabled', 1);
    $device_storage_enabled = get_option('cookie_consent_device_storage_enabled', 1);

    if (empty($message_text)) {
        $message_text = 'Използваме бисквитки за персонализирана реклама и анализ на потребителското поведение. Можете да промените настройките си за бисквитки по всяко време чрез бутоните по-долу или в настройките за поверителност.';
    }

    $advertising_text = get_option('cookie_consent_advertising_text', 'Персонализирана реклама и съдържание, измерване на рекламата и съдържанието, проучване на аудиторията и разработване на услуги');
    $device_storage_text = get_option('cookie_consent_device_storage_text', 'Съхраняване на и/или достъп до информация на устройство');
    
    ?>
    <div id="cookie-consent-modal" class="cookie-consent-modal <?php echo esc_attr($animation); ?>">
        <div class="cookie-consent-content">
            <p>Добре дошли в(ъв) <span id="site-name"><?php echo parse_url(get_bloginfo('url'), PHP_URL_HOST); ?></span></p>
            <h2>
                <?php echo parse_url(get_bloginfo('url'), PHP_URL_HOST); ?> иска съгласие за използване на бисквитки.
            </h2>
            <ul>
                <?php if ($advertising_enabled) : ?>
                    <li><i class="fas fa-ad"></i> <?php echo esc_html($advertising_text); ?></li>
                <?php endif; ?>

                <?php if ($device_storage_enabled) : ?>
                    <li><i class="fas fa-mobile-alt"></i> <?php echo esc_html($device_storage_text); ?></li>
                <?php endif; ?>
            </ul>
            <p><?php echo esc_html($message_text); ?></p>
            <div class="cookie-buttons">
                <button id="accept-cookie-consent" class="accept-button" style="background-color: <?php echo esc_attr($button_color); ?>">Получаване на съгласие</button>
                <button id="decline-cookie-consent" class="decline-button">Отказвам</button>
                <a href="<?php echo esc_url($privacy_link); ?>" class="privacy-link">Научете повече</a>
            </div>
        </div>
    </div>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const acceptButton = document.getElementById('accept-cookie-consent');
            const declineButton = document.getElementById('decline-cookie-consent');

            acceptButton.addEventListener('click', function() {
                document.cookie = "cookie_consent_accepted=true; max-age=" + (<?php echo get_option('cookie_consent_expiration', 30); ?> * 86400) + "; path=/";
                document.getElementById('cookie-consent-modal').style.display = 'none';

                if (typeof gtag !== 'undefined') {
                    gtag('consent', 'update', {
                        'analytics_storage': 'granted',
                        'ad_storage': 'granted'
                    });
                }
            });

            declineButton.addEventListener('click', function() {
                document.cookie = "cookie_consent_accepted=false; max-age=" + (<?php echo get_option('cookie_consent_expiration', 30); ?> * 86400) + "; path=/";
                document.getElementById('cookie-consent-modal').style.display = 'none';

                if (typeof gtag !== 'undefined') {
                    gtag('consent', 'update', {
                        'analytics_storage': 'denied',
                        'ad_storage': 'denied'
                    });
                }
            });
        });
    </script>
    <?php
}

add_action('wp_footer', 'cookie_consent_banner', 100);
?>
