document.addEventListener('DOMContentLoaded', function() {

    // Проверяваме дали вече има съхранено състояние на съгласието
    if (!localStorage.getItem('cookie-consent')) {
        // Ако няма, показваме банера
        document.getElementById('cookie-consent-modal').style.display = 'flex';
    } else {
        // Ако има съхранено състояние, прилагаме съответните настройки на съгласие
        updateConsentStatus(localStorage.getItem('cookie-consent'));
    }

    // Когато потребителят приеме съгласието
    document.getElementById('accept-cookie-consent').addEventListener('click', function() {
        // Записваме съгласието в localStorage
        localStorage.setItem('cookie-consent', 'accepted');
        
        // Обновяваме състоянието на съгласието
        updateConsentStatus('accepted');
        
        // Скриваме банера
        document.getElementById('cookie-consent-modal').style.display = 'none';
    });

    // Когато потребителят откаже съгласието
    document.getElementById('decline-cookie-consent').addEventListener('click', function() {
        // Записваме отказа в localStorage
        localStorage.setItem('cookie-consent', 'declined');
        
        // Обновяваме състоянието на съгласието
        updateConsentStatus('declined');
        
        // Скриваме банера
        document.getElementById('cookie-consent-modal').style.display = 'none';
    });

    // Функция за обновяване на състоянието на съгласието с Google Consent Mode
    function updateConsentStatus(consentStatus) {
        if (typeof gtag !== 'undefined') {
            if (consentStatus === 'accepted') {
                // Потребителят е приел съгласието - разрешаваме аналитични и рекламни бисквитки
                gtag('consent', 'update', {
                    'analytics_storage': 'granted',
                    'ad_storage': 'granted'
                });
            } else if (consentStatus === 'declined') {
                // Потребителят е отказал съгласието - блокираме аналитични и рекламни бисквитки
                gtag('consent', 'update', {
                    'analytics_storage': 'denied',
                    'ad_storage': 'denied'
                });
            }
        }
    }
});
